PlotUMAP_fixedwindow: Generate UMAP for the final prediction based on fixed window...

View source: R/VisualizeOutput.R

PlotUMAP_fixedwindowR Documentation

Generate UMAP for the final prediction based on fixed window eg.100kb bin widows

Description

Generate UMAP for the final prediction based on fixed window eg.100kb bin widows

Usage

PlotUMAP_fixedwindow(
  query_fn,
  knowledge_fn,
  prediction_result,
  n_component = 30,
  seed = 123,
  ...
)

Arguments

query_fn

File path to query .cg

knowledge_fn

File path to 100bk bins window or reference pattern

prediction_result

Prediction result from PredictCellType

n_component

Number of PCA components to use (Default: 30)

seed

A number for random seed (Default: 123)

...

Additional arguments passed to 'uwot::umap' (e.g., 'n_neighbors', 'metric').

Value

A list of two ggplot2 UMAP object.


MethScope documentation built on Feb. 27, 2026, 1:08 a.m.