Skip to contents

Predict cell type annotation from the trained model

Usage

PredictCellType(bst_model, predictMatrix, smooth = FALSE, KNeighbor = 5)

Arguments

bst_model

The boosting model trained from ModelTrain

predictMatrix

A wide cell by pattern matrix generated from GenerateInput function

smooth

A Boolean variable to indicate whether smooth the matrix (Default: FALSE)

KNeighbor

number of knn neighbors to use for smoothing (Default: 5)

Value

A cell by cell type matrix with confidence score and labeled cell type.

Examples

if (FALSE) {
# Run from the root of a cloned zhou-lab/MethScope repository.
input_pattern <- GenerateInput("inst/extdata/example.cg",
                               "inst/extdata/mm10_Liu2021.cm")
model <- Liu2021_MouseBrain_P1000()
prediction <- PredictCellType(model, input_pattern)
}