filter_cell: Filter final prediction to reduce noise

View source: R/PredictCellType.R

filter_cellR Documentation

Filter final prediction to reduce noise

Description

Filter final prediction to reduce noise

Usage

filter_cell(pred_result, knn_res, KNeighbor = 5)

Arguments

pred_result

The prediction result from XGBoost

knn_res

knn graph from smooth_matrix

KNeighbor

Number of knn neighbors to use for smoothing (Default: 5)

Value

The final prediction result after dropping few cell types


MethScope documentation built on Feb. 27, 2026, 1:08 a.m.