View source: R/PredictCellType.R
| nnls_deconv | R Documentation |
Estimate cell type relative proportion
nnls_deconv(ref, mixture_matrix, number_patterns = 1000, var_threshold = 0.01)
ref |
An imputed wide cell by pattern matrix generated from GenerateInput function using reference Pseudobulk |
mixture_matrix |
An imputed wide cell by pattern matrix generated from GenerateInput function |
number_patterns |
a numeric value to indicate number of patterns to be used (Default: 1000) |
var_threshold |
a numeric value to indicate variance that should filter the patterns (Default: 0.1) |
A cell type by cell matrix showing the relative cell type proportion estimate for each cells
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.