View source: R/ModelTraining.R
| Input_training | R Documentation |
Train XGBoost model to predict cell type
Input_training(
summary_results,
cell_type_label,
number_patterns = 1000,
cross_validation = FALSE,
xgb_parameters = list()
)
summary_results |
a wide cell by pattern matrix generated from GenerateInput function |
cell_type_label |
a vector of the corresponding cell type label for each row of the summary results |
number_patterns |
a numeric value to indicate number of patterns to be used (Default: 1000) |
cross_validation |
a boolean varaible whether to perform cross_validation to obtain the best hyper parameters for the model |
xgb_parameters |
an optional list for xgb model parameters provided by the user |
the xgb model trained
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.