Generate UMAP for the final prediction based on cell patterns
PlotUMAP(predictMatrix, prediction_result, n_component = 30, seed = 123, ...)A list of two ggplot2 UMAP object.
a wide cell by pattern matrix generated from GenerateInput function
Prediction result from PredictCellType
Number of PCA components to use (Default: 30)
A number for random seed (Default: 123)
Additional arguments passed to `uwot::umap` (e.g., `n_neighbors`, `metric`).