View source: R/PredictCellType.R
| PredictCellType | R Documentation |
Predict cell type annotation from the trained model
PredictCellType(bst_model, predictMatrix, smooth = FALSE, KNeighbor = 5)
bst_model |
The boosting model trained from ModelTrain |
predictMatrix |
A wide cell by pattern matrix generated from GenerateInput function |
smooth |
A Boolean variable to indicate whether smooth the matrix (Default: FALSE) |
KNeighbor |
number of knn neighbors to use for smoothing (Default: 5) |
A cell by cell type matrix with confidence score and labeled cell type.
qry <- system.file("extdata", "toy.cg", package = "MethScope")
msk <- system.file("extdata", "toy.cm", package = "MethScope")
res <- GenerateInput(qry, msk)
## Not run:
prediction <- PredictCellType(Liu2021_MouseBrain_P1000,res)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.