View source: R/PredictCellType.R
| filter_cell | R Documentation |
Filter final prediction to reduce noise
filter_cell(pred_result, knn_res, KNeighbor = 5)
pred_result |
The prediction result from XGBoost |
knn_res |
knn graph from smooth_matrix |
KNeighbor |
Number of knn neighbors to use for smoothing (Default: 5) |
The final prediction result after dropping few cell types
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.