View source: R/PredictCellType.R
| smooth_matrix | R Documentation |
Smooth cell by pattern matrix to reduce noise
smooth_matrix(predictMatrix, KNeighbor = 5)
predictMatrix |
A wide cell by pattern matrix generated from GenerateInput function |
KNeighbor |
Number of knn neighbors to use for smoothing (Default: 5) |
A wide cell by pattern matrix after smoothing and knn graph
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.